@@ -30,7 +30,7 @@ from .exceptions import (
 class MemoryStackClient:
     """Client for interacting with MemoryStack API"""
     
-    SDK_VERSION = "1.0.3"
+    SDK_VERSION = "1.0.4"
 
     def __init__(
         self,
@@ -350,6 +350,11 @@ class MemoryStackClient:
         content: Union[str, List[Message], List[Dict[str, str]]],
         user_id: Optional[str] = None,
         metadata: Optional[Dict[str, Any]] = None,
+        # Scoping fields (stored in dedicated columns, not metadata)
+        agent_id: Optional[str] = None,
+        team_id: Optional[str] = None,
+        session_id: Optional[str] = None,
+        conversation_id: Optional[str] = None,
     ) -> CreateMemoryResponse:
         """
         Add a memory - the simplest way to store information.
@@ -361,6 +366,9 @@ class MemoryStackClient:
             # With user ID (for B2B apps)
             client.add("User prefers dark mode", user_id="user_123")
             
+            # With agent scoping (stored in dedicated column)
+            client.add("User prefers dark mode", agent_id="support-agent")
+            
             # Conversation format
             client.add([
                 {"role": "user", "content": "I love Python"},
@@ -371,6 +379,10 @@ class MemoryStackClient:
             content: Text string or list of messages
             user_id: Optional end user ID for B2B use cases
             metadata: Optional metadata dictionary
+            agent_id: Optional agent ID (stored in dedicated column)
+            team_id: Optional team ID (stored in dedicated column)
+            session_id: Optional session ID (stored in dedicated column)
+            conversation_id: Optional conversation ID (stored in dedicated column)
             
         Returns:
             CreateMemoryResponse with created memory IDs
@@ -397,14 +409,36 @@ class MemoryStackClient:
             if not msg.get('role') or not msg.get('content'):
                 raise ValidationError(f"Message missing role or content: {msg}")
         
-        # Build payload
+        # Resolve scoping fields: explicit args > metadata > instance defaults
+        resolved_agent_id = agent_id or (metadata.get('agent_id') if metadata else None) or self.agent_id
+        resolved_team_id = team_id or (metadata.get('team_id') if metadata else None)
+        resolved_session_id = session_id or (metadata.get('session_id') if metadata else None) or self.session_id
+        resolved_conversation_id = conversation_id or (metadata.get('conversation_id') if metadata else None)
+        
+        # Filter out scoping fields from metadata (they go to top level)
+        clean_metadata = None
+        if metadata:
+            clean_metadata = {k: v for k, v in metadata.items() 
+                           if k not in ['agent_id', 'team_id', 'session_id', 'conversation_id']}
+            if not clean_metadata:
+                clean_metadata = None
+        
+        # Build payload - scoping fields at top level for proper column storage
         payload = {"messages": messages}
         if user_id is not None:
             payload["user_id"] = user_id
-        if metadata is not None:
-            payload["metadata"] = metadata
-        if self.session_id:
-            payload["session_id"] = self.session_id
+        if clean_metadata is not None:
+            payload["metadata"] = clean_metadata
+        # Scoping fields at top level
+        if resolved_agent_id:
+            payload["agent_id"] = resolved_agent_id
+        if resolved_team_id:
+            payload["team_id"] = resolved_team_id
+        if resolved_session_id:
+            payload["session_id"] = resolved_session_id
+        if resolved_conversation_id:
+            payload["conversation_id"] = resolved_conversation_id
+        # Agent name/type for auto-registration
         if self.agent_name:
             payload["agent_name"] = self.agent_name
         if self.agent_type:
@@ -570,6 +604,7 @@ class MemoryStackClient:
         query: str,
         user_id: Optional[str] = None,
         limit: int = 10,
+        **kwargs
     ) -> Dict[str, Any]:
         """
         Search memories - find relevant information.
@@ -578,8 +613,8 @@ class MemoryStackClient:
             # Simple search
             results = client.search("user preferences")
             
-            # With user ID (for B2B apps)
-            results = client.search("user preferences", user_id="user_123")
+            # With filters
+            results = client.search("user preferences", user_id="user_123", agent_id="support_bot")
             
             # With limit
             results = client.search("user preferences", limit=5)
@@ -588,6 +623,7 @@ class MemoryStackClient:
             query: Search query
             user_id: Optional end user ID filter
             limit: Maximum results (1-50, default: 10)
+            **kwargs: Additional parameters passed to search API (e.g., agent_id, team_id, session_id, memory_type)
             
         Returns:
             Dict with 'success', 'count', and 'results' keys
@@ -605,6 +641,10 @@ class MemoryStackClient:
         }
         if user_id:
             params["user_id"] = user_id
+            
+        # Add any other provided keywords to params
+        if kwargs:
+            params.update(kwargs)
         
         response = self._make_request('GET', f"{self.base_url}/memories/search", params=params)
         data = self._handle_response(response)
@@ -645,42 +685,6 @@ class MemoryStackClient:
     ) -> Dict[str, Any]:
         """Deprecated: Use search() instead - simpler API"""
         return self.search(query, user_id=user_id, limit=limit)
-        params = {
-            "query": query,
-            "limit": limit,
-            "mode": mode,
-        }
-        
-        if user_id:
-            params["user_id"] = user_id
-        
-        # Metadata filters (JSONB column)
-        if agent_id:
-            params["agent_id"] = agent_id
-        if conversation_id:
-            params["conversation_id"] = conversation_id
-        if session_id:
-            params["session_id"] = session_id
-        if team_id:
-            params["team_id"] = team_id
-        
-        if memory_type:
-            params["memory_type"] = memory_type
-        if min_confidence is not None:
-            params["min_confidence"] = min_confidence
-        if threshold is not None:
-            params["threshold"] = threshold
-        
-        response = self._make_request('GET', f"{self.base_url}/memories/search", params=params)
-        data = self._handle_response(response)
-        
-        # Return dict with mode included
-        return {
-            "success": data.get("success", True),
-            "count": len(data.get("results", [])),
-            "mode": data.get("mode", mode),
-            "results": data.get("results", [])
-        }
 
     # Serialization helpers
 
@@ -943,181 +947,24 @@ class MemoryStackClient:
 
         return data
 
-    def detect_contradictions(
-        self,
-        content: str,
-        user_id: Optional[str] = None,
-        confidence: float = 0.8,
-    ) -> Dict[str, Any]:
-        """
-        Detect if new content contradicts existing memories
-        
-        Args:
-            content: New memory content to check
-            user_id: Optional end user ID
-            confidence: Confidence score for new content (0-1)
-            
-        Returns:
-            Dict with contradiction detection results
-        """
-        # Validate content
-        if not content or not content.strip():
-            raise ValidationError("Content is required for contradiction detection")
-        
-        # Validate confidence
-        if not isinstance(confidence, (int, float)) or confidence < 0 or confidence > 1:
-            raise ValidationError(
-                f"Invalid confidence: {confidence}. Must be a number between 0 and 1"
-            )
-        """
-        Detect if new content contradicts existing memories
-        
-        Args:
-            content: New memory content to check
-            user_id: Optional end user ID
-            confidence: Confidence score for new content (0-1)
-            
-        Returns:
-            Dict with contradiction detection results
-        """
-        payload = {
-            "content": content,
-            "confidence": confidence,
-        }
-        if user_id is not None:
-            payload["user_id"] = user_id
-
-        response = self._make_request('POST', f"{self.base_url}/memories/detect-contradictions", json=payload)
-        return self._handle_response(response)
-
-    def update_belief(
-        self,
-        content: str,
-        user_id: Optional[str] = None,
-        confidence: float = 0.8,
-        strategy: str = "auto",
-        contradicting_memory_id: Optional[str] = None,
-        metadata: Optional[Dict[str, Any]] = None,
-    ) -> Dict[str, Any]:
-        """
-        Update belief when new evidence contradicts existing memory
-        
-        Args:
-            content: New memory content
-            user_id: Optional end user ID
-            confidence: Confidence score (0-1)
-            strategy: Resolution strategy ('auto', 'supersede', 'merge', 'adjust', 'manual')
-            contradicting_memory_id: Specific memory ID to update (optional)
-            metadata: Optional metadata
-            
-        Returns:
-            Dict with update results
-        """
-        # Validate content
-        if not content or not content.strip():
-            raise ValidationError("Content is required for belief update")
-        
-        # Validate confidence
-        if not isinstance(confidence, (int, float)) or confidence < 0 or confidence > 1:
-            raise ValidationError(
-                f"Invalid confidence: {confidence}. Must be a number between 0 and 1"
-            )
-        
-        # Validate strategy
-        if strategy not in ['auto', 'supersede', 'merge', 'adjust', 'manual']:
-            raise ValidationError(
-                f'Invalid strategy: "{strategy}". Must be "auto", "supersede", "merge", "adjust", or "manual"'
-            )
-        """
-        Update belief when new evidence contradicts existing memory
-        
-        Args:
-            content: New memory content
-            user_id: Optional end user ID
-            confidence: Confidence score (0-1)
-            strategy: Resolution strategy ('auto', 'supersede', 'merge', 'adjust', 'manual')
-            contradicting_memory_id: Specific memory ID to update (optional)
-            metadata: Optional metadata
-            
-        Returns:
-            Dict with update results
-        """
-        payload = {
-            "content": content,
-            "confidence": confidence,
-            "strategy": strategy,
-        }
-        if user_id is not None:
-            payload["user_id"] = user_id
-        if contradicting_memory_id is not None:
-            payload["contradicting_memory_id"] = contradicting_memory_id
-        if metadata is not None:
-            payload["metadata"] = metadata
-
-        response = self._make_request('POST', f"{self.base_url}/memories/update-belief", json=payload)
-        return self._handle_response(response)
-
-    def get_memory_lineage(
-        self,
-        memory_id: str,
-        format: str = "full",
-    ) -> Dict[str, Any]:
-        """
-        Get complete provenance and lineage of a memory
-        
-        Args:
-            memory_id: Memory ID to get lineage for
-            format: Response format ('full', 'timeline', or 'chain')
-            
-        Returns:
-            Dict with lineage information
-        """
-        # Validate memory_id
-        if not memory_id or not memory_id.strip():
-            raise ValidationError("Memory ID is required")
-        
-        # Validate format
-        if format not in ['full', 'timeline', 'chain']:
-            raise ValidationError(
-                f'Invalid format: "{format}". Must be "full", "timeline", or "chain"'
-            )
-        """
-        Get complete provenance and lineage of a memory
-        
-        Args:
-            memory_id: Memory ID to get lineage for
-            format: Response format ('full', 'timeline', or 'chain')
-            
-        Returns:
-            Dict with lineage information
-        """
-        params = {"format": format}
-        
-        response = self._make_request('GET', f"{self.base_url}/memories/{memory_id}/lineage", params=params)
-        return self._handle_response(response)
-
     def reflect_on_memories(
         self,
         time_window_days: int = 7,
         analysis_depth: str = "shallow",
         dry_run: bool = False,
         min_pattern_strength: float = 0.7,
-        use_batch: bool = False,
     ) -> Dict[str, Any]:
         """
         Run reflection analysis on memories to generate insights
         
-        Automatically uses batch API for >100 memories (50% cost savings)
-        
         Args:
             time_window_days: Number of days to analyze (1-90)
             analysis_depth: 'shallow' or 'deep' analysis
             dry_run: Preview insights without storing
             min_pattern_strength: Minimum pattern strength (0-1)
-            use_batch: Force batch mode even for small memory sets
             
         Returns:
-            Dict with reflection results or batch job info
+            Dict with reflection results
         """
         # Validate time_window_days
         if not isinstance(time_window_days, int) or time_window_days < 1 or time_window_days > 90:
@@ -1136,170 +983,54 @@ class MemoryStackClient:
             raise ValidationError(
                 f"Invalid min_pattern_strength: {min_pattern_strength}. Must be a number between 0 and 1"
             )
-        """
-        Run reflection analysis on memories to generate insights
         
-        Automatically uses batch API for >100 memories (50% cost savings)
-        
-        Args:
-            time_window_days: Number of days to analyze (1-90)
-            analysis_depth: 'shallow' or 'deep' analysis
-            dry_run: Preview insights without storing
-            min_pattern_strength: Minimum pattern strength (0-1)
-            use_batch: Force batch mode even for small memory sets
-            
-        Returns:
-            Dict with reflection results or batch job info
-        """
         payload = {
             "timeWindowDays": time_window_days,
             "analysisDepth": analysis_depth,
             "dryRun": dry_run,
             "minPatternStrength": min_pattern_strength,
-            "useBatch": use_batch,
         }
 
         response = self._make_request('POST', f"{self.base_url}/memories/reflect", json=payload)
         return self._handle_response(response)
 
-    def get_batch_job_status(
-        self,
-        job_id: str,
-    ) -> Dict[str, Any]:
-        """
-        Get status of a batch job
-        
-        Args:
-            job_id: Batch job ID from reflect or consolidate response
-            
-        Returns:
-            Dict with job status and progress
-        """
-        # Validate job_id
-        if not job_id or not job_id.strip():
-            raise ValidationError("Job ID is required")
-        """
-        Get status of a batch job
-        
-        Args:
-            job_id: Batch job ID from reflect or consolidate response
-            
-        Returns:
-            Dict with job status and progress
-        """
-        response = self._make_request('GET', f"{self.base_url}/batch-jobs/{job_id}")
-        return self._handle_response(response)
-
     def import_memories(
         self,
         memories: List[Dict[str, Any]],
-        use_batch: bool = True,
     ) -> Dict[str, Any]:
         """
-        Import memories from another platform
+        Import memories
         
         Args:
             memories: List of memory objects to import
-            use_batch: Use batch create for large imports (recommended)
             
         Returns:
             Dict with import results
         """
-        if use_batch and len(memories) > 10:
-            # Use batch create endpoint for efficiency
-            return self.create_memories_batch(memories)
-        else:
-            # Use regular import endpoint
-            payload = {
-                "version": "1.0",
-                "memories": memories,
-            }
-
-            response = self._make_request('POST', f"{self.base_url}/memories/import", json=payload)
-            return self._handle_response(response)
-
-    def create_memories_batch(
-        self,
-        memories: List[Dict[str, Any]],
-    ) -> Dict[str, Any]:
-        """
-        Create multiple memories at once (batch operation)
-        
-        More efficient than creating memories one by one
-        
-        Args:
-            memories: List of memory objects with content, metadata, etc.
-            
-        Returns:
-            Dict with batch creation results
-        """
-        # Validate memories array
         if not memories or len(memories) == 0:
-            raise ValidationError("At least one memory is required for batch creation")
+            raise ValidationError("At least one memory is required for import")
         
-        if len(memories) > 1000:
-            raise ValidationError("Maximum 1000 memories per batch request")
-        
-        # Validate each memory
-        for i, memory in enumerate(memories):
-            if not isinstance(memory, dict):
-                raise ValidationError(f"Memory at index {i} must be a dictionary")
-            
-            if 'content' not in memory or not str(memory.get('content', '')).strip():
-                raise ValidationError(f"Memory at index {i} is missing content")
-            
-            if 'confidence' in memory:
-                confidence = memory['confidence']
-                if not isinstance(confidence, (int, float)) or confidence < 0 or confidence > 1:
-                    raise ValidationError(
-                        f"Invalid confidence at index {i}: {confidence}. Must be between 0 and 1"
-                    )
-        """
-        Create multiple memories at once (batch operation)
-        
-        More efficient than creating memories one by one
-        
-        Args:
-            memories: List of memory objects with content, metadata, etc.
-            
-        Returns:
-            Dict with batch creation results
-        """
-        # Use new batch create endpoint
         payload = {
             "memories": memories,
-            "generate_embeddings": True,
         }
-        
-        response = self._make_request('POST', f"{self.base_url}/memories/batch/create", json=payload)
+
+        response = self._make_request('POST', f"{self.base_url}/memories/import", json=payload)
         return self._handle_response(response)
 
     def export_memories(
         self,
         format: str = "json",
         user_id: Optional[str] = None,
-        memory_type: Optional[str] = None,
-        min_confidence: Optional[float] = None,
-        include_embeddings: bool = False,
-        date_from: Optional[str] = None,
-        date_to: Optional[str] = None,
     ) -> Dict[str, Any]:
         """
-        Export memories in bulk
-        
-        For large exports (>10k memories), creates a batch job
+        Export memories
         
         Args:
             format: Export format ('json' or 'csv')
             user_id: Filter by user ID
-            memory_type: Filter by memory type
-            min_confidence: Minimum confidence threshold
-            include_embeddings: Include embedding vectors
-            date_from: Filter from date (ISO format)
-            date_to: Filter to date (ISO format)
             
         Returns:
-            Dict with export data or batch job info
+            Dict with export data
         """
         payload = {
             "format": format,
@@ -1307,100 +1038,8 @@ class MemoryStackClient:
         
         if user_id is not None:
             payload["user_id"] = user_id
-        if memory_type is not None:
-            payload["memory_type"] = memory_type
-        if min_confidence is not None:
-            payload["min_confidence"] = min_confidence
-        if include_embeddings:
-            payload["include_embeddings"] = include_embeddings
-        if date_from is not None:
-            payload["date_from"] = date_from
-        if date_to is not None:
-            payload["date_to"] = date_to
 
-        response = self._make_request('POST', f"{self.base_url}/memories/batch/export", json=payload)
-        return self._handle_response(response)
-
-    def cancel_batch_job(
-        self,
-        job_id: str,
-    ) -> Dict[str, Any]:
-        """
-        Cancel a running or pending batch job
-        
-        Args:
-            job_id: Batch job ID to cancel
-            
-        Returns:
-            Dict with cancellation result
-        """
-        response = self._make_request('POST', f"{self.base_url}/batch-jobs/{job_id}/cancel")
-        return self._handle_response(response)
-
-    def retry_batch_job(
-        self,
-        job_id: str,
-    ) -> Dict[str, Any]:
-        """
-        Retry a failed batch job
-        
-        Args:
-            job_id: Batch job ID to retry
-            
-        Returns:
-            Dict with new batch job info
-        """
-        response = self._make_request('POST', f"{self.base_url}/batch-jobs/{job_id}/retry")
-        return self._handle_response(response)
-
-    def generate_embeddings_batch(
-        self,
-        memory_ids: Optional[List[str]] = None,
-        user_id: Optional[str] = None,
-        memory_type: Optional[str] = None,
-        regenerate_all: bool = False,
-    ) -> Dict[str, Any]:
-        """
-        Generate or regenerate embeddings for memories
-        
-        Use cases:
-        - Regenerate embeddings after model upgrade
-        - Generate embeddings for imported memories
-        - Fix missing embeddings
-        
-        Automatically uses batch API for >100 memories (50% cost savings)
-        
-        Args:
-            memory_ids: Specific memory IDs to process (optional)
-            user_id: Filter by user ID (optional)
-            memory_type: Filter by memory type (optional)
-            regenerate_all: Regenerate even if embeddings exist
-            
-        Returns:
-            Dict with generation results or batch job info
-        """
-        payload = {
-            "regenerate_all": regenerate_all,
-        }
-        
-        if memory_ids is not None:
-            payload["memory_ids"] = memory_ids
-        if user_id is not None:
-            payload["user_id"] = user_id
-        if memory_type is not None:
-            payload["memory_type"] = memory_type
-
-        response = self._make_request('POST', f"{self.base_url}/memories/batch/embeddings", json=payload)
-        return self._handle_response(response)
-
-    def get_embedding_statistics(self) -> Dict[str, Any]:
-        """
-        Get statistics about embeddings coverage
-        
-        Returns:
-            Dict with embedding statistics and recommendations
-        """
-        response = self._make_request('GET', f"{self.base_url}/memories/batch/embeddings")
+        response = self._make_request('POST', f"{self.base_url}/memories/export", json=payload)
         return self._handle_response(response)
 
     def consolidate_memories(
@@ -1408,46 +1047,28 @@ class MemoryStackClient:
         similarity_threshold: float = 0.90,
         check_redundancy: bool = True,
         dry_run: bool = False,
-        use_batch: bool = False,
     ) -> Dict[str, Any]:
         """
         Consolidate duplicate or similar memories
         
-        Automatically uses batch API for >500 memories (50% cost savings)
-        
         Args:
             similarity_threshold: Similarity threshold (0-1)
             check_redundancy: Check for redundant memories
             dry_run: Preview consolidation without applying
-            use_batch: Force batch mode
             
         Returns:
-            Dict with consolidation results or batch job info
+            Dict with consolidation results
         """
         # Validate similarity_threshold
         if not isinstance(similarity_threshold, (int, float)) or similarity_threshold < 0 or similarity_threshold > 1:
             raise ValidationError(
                 f"Invalid similarity_threshold: {similarity_threshold}. Must be a number between 0 and 1"
             )
-        """
-        Consolidate duplicate or similar memories
         
-        Automatically uses batch API for >500 memories (50% cost savings)
-        
-        Args:
-            similarity_threshold: Similarity threshold (0-1)
-            check_redundancy: Check for redundant memories
-            dry_run: Preview consolidation without applying
-            use_batch: Force batch mode
-            
-        Returns:
-            Dict with consolidation results or batch job info
-        """
         payload = {
             "similarity_threshold": similarity_threshold,
             "check_redundancy": check_redundancy,
             "dry_run": dry_run,
-            "use_batch": use_batch,
         }
 
         response = self._make_request('POST', f"{self.base_url}/memories/consolidate", json=payload)
@@ -1455,96 +1076,6 @@ class MemoryStackClient:
 
 
     # Auto-maintenance configuration methods
-    
-    def configure_auto_consolidation(
-        self,
-        enabled: bool = True,
-        frequency: str = "weekly",
-        similarity_threshold: float = 0.95,
-        notify_on_merge: bool = False,
-    ) -> Dict[str, Any]:
-        """
-        Configure automatic memory consolidation
-        
-        Args:
-            enabled: Enable/disable auto-consolidation
-            frequency: 'daily', 'weekly', or 'monthly'
-            similarity_threshold: Similarity threshold (0-1)
-            notify_on_merge: Send notification when memories are merged
-            
-        Returns:
-            Dict with updated configuration
-        """
-        payload = {
-            "consolidation_enabled": enabled,
-            "consolidation_frequency": frequency,
-            "consolidation_similarity_threshold": similarity_threshold,
-            "consolidation_notify_on_merge": notify_on_merge,
-        }
-
-        response = self._make_request('POST', f"{self.base_url}/auto-maintenance/config",
-            json=payload
-        )
-        return self._handle_response(response)
-
-    def configure_auto_reflection(
-        self,
-        enabled: bool = True,
-        frequency: str = "weekly",
-        time_window_days: int = 7,
-        analysis_depth: str = "shallow",
-        min_pattern_strength: float = 0.7,
-    ) -> Dict[str, Any]:
-        """
-        Configure automatic memory reflection
-        
-        Args:
-            enabled: Enable/disable auto-reflection
-            frequency: 'daily', 'weekly', or 'monthly'
-            time_window_days: Number of days to analyze (1-90)
-            analysis_depth: 'shallow' or 'deep'
-            min_pattern_strength: Minimum pattern strength (0-1)
-            
-        Returns:
-            Dict with updated configuration
-        """
-        payload = {
-            "reflection_enabled": enabled,
-            "reflection_frequency": frequency,
-            "reflection_time_window_days": time_window_days,
-            "reflection_analysis_depth": analysis_depth,
-            "reflection_min_pattern_strength": min_pattern_strength,
-        }
-
-        response = self._make_request('POST', f"{self.base_url}/auto-maintenance/config",
-            json=payload
-        )
-        return self._handle_response(response)
-
-    def configure_auto_embeddings(
-        self,
-        enabled: bool = True,
-        check_frequency: str = "daily",
-    ) -> Dict[str, Any]:
-        """
-        Configure automatic embedding generation
-        
-        Args:
-            enabled: Enable/disable auto-embedding generation
-            check_frequency: 'daily' or 'weekly'
-            
-        Returns:
-            Dict with updated configuration
-        """
-        payload = {
-            "embedding_generation_enabled": enabled,
-            "embedding_check_frequency": check_frequency,
-        }
-
-        response = self._make_request('POST', f"{self.base_url}/auto-maintenance/config",
-            json=payload
-        )
-        return self._handle_response(response)
 
     def get_auto_maintenance_config(self) -> Dict[str, Any]:
         """
@@ -1558,48 +1089,36 @@ class MemoryStackClient:
 
     def update_auto_maintenance_config(
         self,
-        config: Dict[str, Any],
+        consolidation_enabled: Optional[bool] = None,
+        consolidation_frequency: Optional[str] = None,
+        reflection_enabled: Optional[bool] = None,
+        reflection_frequency: Optional[str] = None,
     ) -> Dict[str, Any]:
         """
         Update auto-maintenance configuration
         
         Args:
-            config: Configuration dictionary with any settings to update
+            consolidation_enabled: Enable/disable auto-consolidation
+            consolidation_frequency: 'daily', 'weekly', or 'monthly'
+            reflection_enabled: Enable/disable auto-reflection
+            reflection_frequency: 'daily', 'weekly', or 'monthly'
             
         Returns:
             Dict with updated configuration
         """
+        config = {}
+        if consolidation_enabled is not None:
+            config["consolidation_enabled"] = consolidation_enabled
+        if consolidation_frequency is not None:
+            config["consolidation_frequency"] = consolidation_frequency
+        if reflection_enabled is not None:
+            config["reflection_enabled"] = reflection_enabled
+        if reflection_frequency is not None:
+            config["reflection_frequency"] = reflection_frequency
+        
         response = self._make_request('POST', f"{self.base_url}/auto-maintenance/config",
             json=config
         )
         return self._handle_response(response)
 
-    def disable_auto_maintenance(self) -> Dict[str, Any]:
-        """
-        Disable all auto-maintenance features
-        
-        Returns:
-            Dict with confirmation
-        """
-        payload = {
-            "consolidation_enabled": False,
-            "reflection_enabled": False,
-            "embedding_generation_enabled": False,
-        }
-
-        response = self._make_request('POST', f"{self.base_url}/auto-maintenance/config",
-            json=payload
-        )
-        return self._handle_response(response)
-
-    def reset_auto_maintenance_config(self) -> Dict[str, Any]:
-        """
-        Reset auto-maintenance configuration to defaults
-        
-        Returns:
-            Dict with confirmation
-        """
-        response = self._make_request('DELETE', f"{self.base_url}/auto-maintenance/config")
-        return self._handle_response(response)
-
 
